# eric7.WebBrowser.Download.DownloadUtilities

Module implementing some utility functions for the Download package.

### Global Attributes

None

### Classes

None

### Functions

dataString | Module function to generate a formatted size string.
speedString | Module function to generate a formatted speed string.
timeString | Module function to format the given time.

## dataString

dataString(size)

Module function to generate a formatted size string.

size (int)
  size to be formatted

Return:
  formatted data string

Return Type:
  str

Up

## speedString

speedString(speed)

Module function to generate a formatted speed string.

speed (float)
  speed to be formatted

Return:
  formatted speed string

Return Type:
  str

Up

## timeString

timeString(timeRemaining)

Module function to format the given time.

timeRemaining (float)
  time to be formatted

Return:
  time string

Return Type:
  str

Up